==> estateplat-common-1.2.1-20170720.080205-64-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZj.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/7/20
 * @description 质检主表
 */
@Table(name = "bdc_zj")
public class BdcZj {

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 主键
     */
    @Id
    private String proid;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检信息id
     */
    private String zjxxid;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检编号
     */
    private String zjbh;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检日期
     */
    private Date zjrq;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检人
     */
    private String zjr;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检原因
     */
    private String zjyy;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 备注
     */
    private String bz;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检状态（0：未通过，1：通过）
     */
    private String zjzt;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检评分
     */
    private Double zjpf;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getZjxxid() {
        return zjxxid;
    }

    public void setZjxxid(String zjxxid) {
        this.zjxxid = zjxxid;
    }

    public String getZjbh() {
        return zjbh;
    }

    public void setZjbh(String zjbh) {
        this.zjbh = zjbh;
    }

    public Date getZjrq() {
        return zjrq;
    }

    public void setZjrq(Date zjrq) {
        this.zjrq = zjrq;
    }

    public String getZjr() {
        return zjr;
    }

    public void setZjr(String zjr) {
        this.zjr = zjr;
    }

    public String getZjyy() {
        return zjyy;
    }

    public void setZjyy(String zjyy) {
        this.zjyy = zjyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZjzt() {
        return zjzt;
    }

    public void setZjzt(String zjzt) {
        this.zjzt = zjzt;
    }

    public Double getZjpf() {
        return zjpf;
    }

    public void setZjpf(Double zjpf) {
        this.zjpf = zjpf;
    }
}

==> estateplat-common-1.2.4-20210913.005643-868-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZj.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/7/20
 * @description 质检主表
 */
@Table(name = "bdc_zj")
public class BdcZj {

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 主键
     */
    @Id
    private String zjid;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 项目id
     */
    private String proid;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检编号
     */
    private String zjbh;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检日期
     */
    private Date zjrq;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检人
     */
    private String zjr;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检原因
     */
    private String zjyy;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 备注
     */
    private String bz;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检状态（0：未通过，1：通过）
     */
    private String zjzt;

    /**
     * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
     * @description 质检评分
     */
    private Double zjpf;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getZjid() {
        return zjid;
    }

    public void setZjid(String zjid) {
        this.zjid = zjid;
    }

    public String getZjbh() {
        return zjbh;
    }

    public void setZjbh(String zjbh) {
        this.zjbh = zjbh;
    }

    public Date getZjrq() {
        return zjrq;
    }

    public void setZjrq(Date zjrq) {
        this.zjrq = zjrq;
    }

    public String getZjr() {
        return zjr;
    }

    public void setZjr(String zjr) {
        this.zjr = zjr;
    }

    public String getZjyy() {
        return zjyy;
    }

    public void setZjyy(String zjyy) {
        this.zjyy = zjyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZjzt() {
        return zjzt;
    }

    public void setZjzt(String zjzt) {
        this.zjzt = zjzt;
    }

    public Double getZjpf() {
        return zjpf;
    }

    public void setZjpf(Double zjpf) {
        this.zjpf = zjpf;
    }
}
